abjadbooktools.AbjadBookScript
==============================

.. abjad-lineage:: abjad.tools.abjadbooktools.AbjadBookScript.AbjadBookScript

.. autoclass:: abjad.tools.abjadbooktools.AbjadBookScript.AbjadBookScript

.. only:: html

   Attribute summary
   -----------------

   .. autosummary::

      ~abjad.tools.abjadbooktools.AbjadBookScript.AbjadBookScript.alias
      ~abjad.tools.abjadbooktools.AbjadBookScript.AbjadBookScript.argument_parser
      ~abjad.tools.abjadbooktools.AbjadBookScript.AbjadBookScript.colors
      ~abjad.tools.abjadbooktools.AbjadBookScript.AbjadBookScript.formatted_help
      ~abjad.tools.abjadbooktools.AbjadBookScript.AbjadBookScript.formatted_usage
      ~abjad.tools.abjadbooktools.AbjadBookScript.AbjadBookScript.formatted_version
      ~abjad.tools.abjadbooktools.AbjadBookScript.AbjadBookScript.long_description
      ~abjad.tools.abjadbooktools.AbjadBookScript.AbjadBookScript.output_formats
      ~abjad.tools.abjadbooktools.AbjadBookScript.AbjadBookScript.process_args
      ~abjad.tools.abjadbooktools.AbjadBookScript.AbjadBookScript.program_name
      ~abjad.tools.abjadbooktools.AbjadBookScript.AbjadBookScript.scripting_group
      ~abjad.tools.abjadbooktools.AbjadBookScript.AbjadBookScript.setup_argument_parser
      ~abjad.tools.abjadbooktools.AbjadBookScript.AbjadBookScript.short_description
      ~abjad.tools.abjadbooktools.AbjadBookScript.AbjadBookScript.version
      ~abjad.tools.abjadbooktools.AbjadBookScript.AbjadBookScript.__call__
      ~abjad.tools.abjadbooktools.AbjadBookScript.AbjadBookScript.__eq__
      ~abjad.tools.abjadbooktools.AbjadBookScript.AbjadBookScript.__format__
      ~abjad.tools.abjadbooktools.AbjadBookScript.AbjadBookScript.__hash__
      ~abjad.tools.abjadbooktools.AbjadBookScript.AbjadBookScript.__ne__
      ~abjad.tools.abjadbooktools.AbjadBookScript.AbjadBookScript.__repr__

Bases
-----

- :py:class:`developerscripttools.DeveloperScript <abjad.tools.developerscripttools.DeveloperScript.DeveloperScript>`

- :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject>`

- :py:class:`abctools.AbjadObject.AbstractBase <abjad.tools.abctools.AbjadObject.AbstractBase>`

- :py:class:`__builtin__.object <object>`

Read-only properties
--------------------

.. autoattribute:: abjad.tools.abjadbooktools.AbjadBookScript.AbjadBookScript.alias
   :noindex:

.. autoattribute:: abjad.tools.abjadbooktools.AbjadBookScript.AbjadBookScript.argument_parser
   :noindex:

.. autoattribute:: abjad.tools.abjadbooktools.AbjadBookScript.AbjadBookScript.colors
   :noindex:

.. autoattribute:: abjad.tools.abjadbooktools.AbjadBookScript.AbjadBookScript.formatted_help
   :noindex:

.. autoattribute:: abjad.tools.abjadbooktools.AbjadBookScript.AbjadBookScript.formatted_usage
   :noindex:

.. autoattribute:: abjad.tools.abjadbooktools.AbjadBookScript.AbjadBookScript.formatted_version
   :noindex:

.. autoattribute:: abjad.tools.abjadbooktools.AbjadBookScript.AbjadBookScript.long_description
   :noindex:

.. autoattribute:: abjad.tools.abjadbooktools.AbjadBookScript.AbjadBookScript.output_formats
   :noindex:

.. autoattribute:: abjad.tools.abjadbooktools.AbjadBookScript.AbjadBookScript.program_name
   :noindex:

.. autoattribute:: abjad.tools.abjadbooktools.AbjadBookScript.AbjadBookScript.scripting_group
   :noindex:

.. autoattribute:: abjad.tools.abjadbooktools.AbjadBookScript.AbjadBookScript.short_description
   :noindex:

.. autoattribute:: abjad.tools.abjadbooktools.AbjadBookScript.AbjadBookScript.version
   :noindex:

Methods
-------

.. automethod:: abjad.tools.abjadbooktools.AbjadBookScript.AbjadBookScript.process_args
   :noindex:

.. automethod:: abjad.tools.abjadbooktools.AbjadBookScript.AbjadBookScript.setup_argument_parser
   :noindex:

Special methods
---------------

.. automethod:: abjad.tools.abjadbooktools.AbjadBookScript.AbjadBookScript.__call__
   :noindex:

.. automethod:: abjad.tools.abjadbooktools.AbjadBookScript.AbjadBookScript.__eq__
   :noindex:

.. automethod:: abjad.tools.abjadbooktools.AbjadBookScript.AbjadBookScript.__format__
   :noindex:

.. automethod:: abjad.tools.abjadbooktools.AbjadBookScript.AbjadBookScript.__hash__
   :noindex:

.. automethod:: abjad.tools.abjadbooktools.AbjadBookScript.AbjadBookScript.__ne__
   :noindex:

.. automethod:: abjad.tools.abjadbooktools.AbjadBookScript.AbjadBookScript.__repr__
   :noindex:
